@@ -27,7 +27,7 @@
 #' @param by data variable name by which the data is split, or a vector of two variable names to split the data by two variables (where the first is used for the rows and the second for the columns). See also \code{\link{tm_facets}}
 #' @param scale numeric value that serves as the global scale parameter. All font sizes, symbol sizes, border widths, and line widths are controlled by this value. The parameters \code{symbols.size}, \code{text.size}, and \code{lines.lwd} can be scaled seperately with respectively \code{symbols.scale}, \code{text.scale}, and \code{lines.scale}. See also \code{...}.
 #' @param title main title. For legend titles, use \code{X.style}, where X is the layer name (see \code{...}).
-#' @param projection Either a \code{\link[sf:st_crs]{crs}} object or a character value. If it is a character, it can either be a \code{PROJ.4} character string or a shortcut. See \code{\link[tmaptools:get_proj4]{get_proj4}} for a list of shortcut values. By default, the projection is used that is defined in the \code{shp} object itself, which can be obtained with \code{\link[tmaptools:get_projection]{get_projection}}.
+#' @param projection Either a \code{\link[sf:st_crs]{crs}} object or a character value (\code{PROJ.4} character string). By default, the projection is used that is defined in the \code{shp} object itself.
 #' @param bbox bounding box. Arugment passed on to \code{\link{tm_shape}}
 #' @param basemaps name(s) of the provider or an URL of a tiled basemap. It is a shortcut to \code{\link{tm_basemap}}. Set to \code{NULL} to disable basemaps. By default, it is set to the tmap option \code{basemaps}.
 #' @param overlays name(s) of the provider or an URL of a tiled overlay map. It is a shortcut to \code{\link{tm_tiles}}.
@@ -86,7 +86,7 @@ qtm <- function(shp,
 	}
 	
 	
-	isRaster <- (inherits(shp, c("SpatialGrid", "SpatialPixels", "Raster")))
+	isRaster <- (inherits(shp, c("SpatialGrid", "SpatialPixels", "Raster", "stars")))
 	
 	if (isRaster) {
 		fill <- NULL
@@ -231,6 +231,7 @@ qtm <- function(shp,
 	if (!is.null(raster)) {
 		g <- g + do.call("tm_raster", c(list(col=raster), args2[["tm_raster"]]))
 		g$tm_raster$is.RGB <- is.RGB
+		g$tm_raster$rgb.vars <- if (identical(is.RGB, TRUE)) c(1,2,3) else NULL
 	}
 
 	
