@@ -76,7 +76,7 @@ tm_facets <- function(by=NULL,
 #' @param y y coordinates for horizontal grid lines. If \code{NA}, it is specified with a pretty scale and \code{n.y}.
 #' @param n.x preferred number of grid lines for the x axis. For the labels, a \code{\link{pretty}} sequence is used, so the number of actual labels may be different than \code{n.x}.
 #' @param n.y preferred number of grid lines for the y axis. For the labels, a \code{\link{pretty}} sequence is used, so the number of actual labels may be different than \code{n.y}.
-#' @param projection projection character. If specified, the grid lines are projected accordingly. See \code{\link[tmaptools:set_projection]{set_projection}} for projection details. Many world maps are projected, but still have latitude longitude (\code{"longlat"}) grid lines.
+#' @param projection projection character. If specified, the grid lines are projected accordingly. Many world maps are projected, but still have latitude longitude (epsg 4326) grid lines.
 #' @param col color of the grid lines.
 #' @param lwd line width of the grid lines
 #' @param alpha alpha transparency of the grid lines. Number between 0 and 1. By default, the alpha transparency of \code{col} is taken. 
@@ -142,7 +142,7 @@ tm_graticules <- function(x=NA,
 						 y=NA,
 						 n.x=NA,
 						 n.y=NA,
-						 projection = "longlat",
+						 projection = 4326,
 						 labels.format = list(suffix = intToUtf8(176)),
 						 labels.cardinal = TRUE,
 						 ...) {
